(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17143,        461]*)
(*NotebookOutlinePosition[     17848,        485]*)
(*  CellTagsIndexPosition[     17804,        481]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Example 7. Equality of Circumplex Structure in Two Groups", "Title"],

Cell[BoxData[
    \(<< Statistics`DescriptiveStatistics`\)], "Input"],

Cell[BoxData[
    \(<< Statistics`MultinormalDistribution`\)], "Input"],

Cell[BoxData[
    \(<< Statistics`MultiDescriptiveStatistics`\)], "Input"],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"circumplexForm6x6", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {
                "1", \(\[Rho]\_1\), \(\[Rho]\_2\), \(\[Rho]\_3\), \(\[Rho]\_2\
\), \(\[Rho]\_1\)},
              {\(\[Rho]\_1\), 
                "1", \(\[Rho]\_1\), \(\[Rho]\_2\), \(\[Rho]\_3\), \(\[Rho]\_2\
\)},
              {\(\[Rho]\_2\), \(\[Rho]\_1\), 
                "1", \(\[Rho]\_1\), \(\[Rho]\_2\), \(\[Rho]\_3\)},
              {\(\[Rho]\_3\), \(\[Rho]\_2\), \(\[Rho]\_1\), 
                "1", \(\[Rho]\_1\), \(\[Rho]\_2\)},
              {\(\[Rho]\_2\), \(\[Rho]\_3\), \(\[Rho]\_2\), \(\[Rho]\_1\), 
                "1", \(\[Rho]\_1\)},
              {\(\[Rho]\_1\), \(\[Rho]\_2\), \(\[Rho]\_3\), \(\[Rho]\_2\), \(\
\[Rho]\_1\), "1"}
              }], ")"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(populationMatrix\  = \ 
      circumplexForm6x6\  /. \ {\[Rho]\_3 \[Rule]  .2, \[Rho]\_2 \[Rule]  .4, \
\ \[Rho]\_1 \[Rule]  .6}; MatrixForm[populationMatrix]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0.6`", "0.4`", "0.2`", "0.4`", "0.6`"},
            {"0.6`", "1", "0.6`", "0.4`", "0.2`", "0.4`"},
            {"0.4`", "0.6`", "1", "0.6`", "0.4`", "0.2`"},
            {"0.2`", "0.4`", "0.6`", "1", "0.6`", "0.4`"},
            {"0.4`", "0.2`", "0.4`", "0.6`", "1", "0.6`"},
            {"0.6`", "0.4`", "0.2`", "0.4`", "0.6`", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(populationDistribution = \
\[IndentingNewLine]MultinormalDistribution[{0, 0, 0, 0, 0, 0}, 
          populationMatrix];\)\)], "Input"],

Cell[BoxData[
    \(SeedRandom[123]\)], "Input"],

Cell[BoxData[
    \(\(data1 = RandomArray[populationDistribution, 500];\)\)], "Input"],

Cell[BoxData[
    \(\(data2 = RandomArray[populationDistribution, 250];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"circumplexHypothesis1", "=", 
        RowBox[{"(", GridBox[{
              {"1", "2", "1", "1", "0"},
              {"1", "3", "2", "1", "0"},
              {"1", "4", "3", "1", "0"},
              {"1", "5", "4", "1", "0"},
              {"1", "6", "5", "1", "0"},
              {"1", "3", "1", "2", "0"},
              {"1", "4", "2", "2", "0"},
              {"1", "5", "3", "2", "0"},
              {"1", "6", "4", "2", "0"},
              {"1", "4", "1", "3", "0"},
              {"1", "5", "2", "3", "0"},
              {"1", "6", "3", "3", "0"},
              {"1", "5", "1", "2", "0"},
              {"1", "6", "2", "2", "0"},
              {"1", "6", "1", "1", "0"}
              }], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"circumplexHypothesis2", "=", 
        RowBox[{"(", GridBox[{
              {"2", "2", "1", "1", "0"},
              {"2", "3", "2", "1", "0"},
              {"2", "4", "3", "1", "0"},
              {"2", "5", "4", "1", "0"},
              {"2", "6", "5", "1", "0"},
              {"2", "3", "1", "2", "0"},
              {"2", "4", "2", "2", "0"},
              {"2", "5", "3", "2", "0"},
              {"2", "6", "4", "2", "0"},
              {"2", "4", "1", "3", "0"},
              {"2", "5", "2", "3", "0"},
              {"2", "6", "3", "3", "0"},
              {"2", "5", "1", "2", "0"},
              {"2", "6", "2", "2", "0"},
              {"2", "6", "1", "1", "0"}
              }], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(\(circumplexHypothesis = 
        AppendColumns[circumplexHypothesis1, 
          circumplexHypothesis2];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeChiSquare[{data1, data2}, 
      circumplexHypothesis, \[IndentingNewLine]{500, 250}, 
      DataType \[Rule] RawData]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"WBCORR Output\"\>",
        "Subsection"],
      (StyleForm[ #, "Subsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"Hypothesis Matrix\"\>",
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Group\"\>", "\<\"Row\"\>", "\<\"Column\"\>", "\<\"Parameter \
Tag\"\>", "\<\"Fixed Value\"\>"},
          {"1", "2", "1", "1", "0"},
          {"1", "3", "2", "1", "0"},
          {"1", "4", "3", "1", "0"},
          {"1", "5", "4", "1", "0"},
          {"1", "6", "5", "1", "0"},
          {"1", "3", "1", "2", "0"},
          {"1", "4", "2", "2", "0"},
          {"1", "5", "3", "2", "0"},
          {"1", "6", "4", "2", "0"},
          {"1", "4", "1", "3", "0"},
          {"1", "5", "2", "3", "0"},
          {"1", "6", "3", "3", "0"},
          {"1", "5", "1", "2", "0"},
          {"1", "6", "2", "2", "0"},
          {"1", "6", "1", "1", "0"},
          {"2", "2", "1", "1", "0"},
          {"2", "3", "2", "1", "0"},
          {"2", "4", "3", "1", "0"},
          {"2", "5", "4", "1", "0"},
          {"2", "6", "5", "1", "0"},
          {"2", "3", "1", "2", "0"},
          {"2", "4", "2", "2", "0"},
          {"2", "5", "3", "2", "0"},
          {"2", "6", "4", "2", "0"},
          {"2", "4", "1", "3", "0"},
          {"2", "5", "2", "3", "0"},
          {"2", "6", "3", "3", "0"},
          {"2", "5", "1", "2", "0"},
          {"2", "6", "2", "2", "0"},
          {"2", "6", "1", "1", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Group", "Row", "Column", 
          "Parameter Tag", "Fixed Value"}}]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[
        InterpretationBox[\("Input Correlation Matrix "\[InvisibleSpace]1\
\[InvisibleSpace]"   Sample Size = "\[InvisibleSpace]500\),
          SequenceForm[ 
          "Input Correlation Matrix ", 1, "   Sample Size = ", 500],
          Editable->False],
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9999999999999991`", "0.5986026170815626`", 
              "0.4170620409504569`", "0.23398656447637883`", 
              "0.415226926659772`", "0.5939910875789979`"},
            {"0.5986026170815626`", "0.9999999999999996`", 
              "0.6200321587566612`", "0.4175262362175609`", 
              "0.18795861468809186`", "0.35393388003856086`"},
            {"0.4170620409504569`", "0.6200321587566612`", 
              "1.0000000000000009`", "0.5803561812509817`", 
              "0.3963850612689276`", "0.19965756954498565`"},
            {"0.23398656447637883`", "0.4175262362175609`", 
              "0.5803561812509817`", "1.0000000000000004`", 
              "0.6165857282043702`", "0.43360160879329357`"},
            {"0.415226926659772`", "0.18795861468809186`", 
              "0.3963850612689276`", "0.6165857282043702`", 
              "1.0000000000000007`", "0.6236764380498441`"},
            {"0.5939910875789979`", "0.35393388003856086`", 
              "0.19965756954498565`", "0.43360160879329357`", 
              "0.6236764380498441`", "1.000000000000001`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[
        InterpretationBox[\("Input Correlation Matrix "\[InvisibleSpace]2\
\[InvisibleSpace]"   Sample Size = "\[InvisibleSpace]250\),
          SequenceForm[ 
          "Input Correlation Matrix ", 2, "   Sample Size = ", 250],
          Editable->False],
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.000000000000001`", "0.6120535346790938`", 
              "0.5163458655598275`", "0.28855638297580183`", 
              "0.43687456318694184`", "0.5568761884963136`"},
            {"0.6120535346790938`", "0.9999999999999996`", 
              "0.6129466858010983`", "0.3510865024960523`", 
              "0.16640641855701546`", "0.2911712120366989`"},
            {"0.5163458655598275`", "0.6129466858010983`", 
              "1.0000000000000004`", "0.5293789951292073`", 
              "0.4577926491034343`", "0.15570159479076598`"},
            {"0.28855638297580183`", "0.3510865024960523`", 
              "0.5293789951292073`", "1.0000000000000004`", 
              "0.6246967937042844`", "0.38726682865531403`"},
            {"0.43687456318694184`", "0.16640641855701546`", 
              "0.4577926491034343`", "0.6246967937042844`", "1.`", 
              "0.5631824129046136`"},
            {"0.5568761884963136`", "0.2911712120366989`", 
              "0.15570159479076598`", "0.38726682865531403`", 
              "0.5631824129046136`", "1.0000000000000002`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[
        InterpretationBox[\("OLS Estimates of Correlation Matrix "\
\[InvisibleSpace]1\),
          SequenceForm[ "OLS Estimates of Correlation Matrix ", 1],
          Editable->False],
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9999999999999991`", "0.5981001290816007`", 
              "0.406000001971677`", "0.2059871685786947`", 
              "0.406000001971677`", "0.5981001290816007`"},
            {"0.5981001290816007`", "0.9999999999999996`", 
              "0.5981001290816007`", "0.406000001971677`", 
              "0.2059871685786947`", "0.406000001971677`"},
            {"0.406000001971677`", "0.5981001290816007`", 
              "1.0000000000000009`", "0.5981001290816007`", 
              "0.406000001971677`", "0.2059871685786947`"},
            {"0.2059871685786947`", "0.406000001971677`", 
              "0.5981001290816007`", "1.0000000000000004`", 
              "0.5981001290816007`", "0.406000001971677`"},
            {"0.406000001971677`", "0.2059871685786947`", 
              "0.406000001971677`", "0.5981001290816007`", 
              "1.0000000000000007`", "0.5981001290816007`"},
            {"0.5981001290816007`", "0.406000001971677`", 
              "0.2059871685786947`", "0.406000001971677`", 
              "0.5981001290816007`", "1.000000000000001`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[
        InterpretationBox[\("OLS Estimates of Correlation Matrix "\
\[InvisibleSpace]2\),
          SequenceForm[ "OLS Estimates of Correlation Matrix ", 2],
          Editable->False],
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.000000000000001`", "0.5981001290816007`", 
              "0.406000001971677`", "0.2059871685786947`", 
              "0.406000001971677`", "0.5981001290816007`"},
            {"0.5981001290816007`", "0.9999999999999996`", 
              "0.5981001290816007`", "0.406000001971677`", 
              "0.2059871685786947`", "0.406000001971677`"},
            {"0.406000001971677`", "0.5981001290816007`", 
              "1.0000000000000004`", "0.5981001290816007`", 
              "0.406000001971677`", "0.2059871685786947`"},
            {"0.2059871685786947`", "0.406000001971677`", 
              "0.5981001290816007`", "1.0000000000000004`", 
              "0.5981001290816007`", "0.406000001971677`"},
            {"0.406000001971677`", "0.2059871685786947`", 
              "0.406000001971677`", "0.5981001290816007`", "1.`", 
              "0.5981001290816007`"},
            {"0.5981001290816007`", "0.406000001971677`", 
              "0.2059871685786947`", "0.406000001971677`", 
              "0.5981001290816007`", "1.0000000000000002`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"2-Stage GLS Parameter Estimates\"\>",
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Parameter Tag\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\
\>"},
          {"1", "0.598100129081601`", "0.01282519056283833`"},
          {"2", "0.40600000197167696`", "0.019966756126358957`"},
          {"3", "0.205987168578694`", "0.026754370121158236`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Parameter Tag", "Estimate", 
          "Standard Error"}}]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"Significance Test Results\"\>",
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Chi Square\"\>", "\<\"df\"\>", "\<\"plevel\"\>"},
          {"33.13351305886531`", "27", "0.19269954829587188`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {None, {"Chi Square", "df", 
          "plevel"}}]]]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"Assessment of Multivariate Normality\"\>",
        "Subsubsection"],
      (StyleForm[ #, "Subsubsection"]&)]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Multivariate Skewness\"\>", "\<\"Chi Square\"\>", \
"\<\"df\"\>", "\<\"plevel\"\>"},
          {"1", "0.6666459557584725`", "55.55382964653938`", "56", 
            "0.4916956366308729`"},
          {"2", "1.201358078909321`", "50.056586621221705`", "56", 
            "0.6981807115007166`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"Multivariate Skewness", 
          "Chi Square", "df", "plevel"}}]]]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Multivariate Kurtosis\"\>", "\<\"Z\"\>", \
"\<\"plevel (2-tailed)\"\>"},
          {"1", "48.37776432136824`", "0.6497143033838042`", 
            "0.5158767829660325`"},
          {"2", "47.76939910489495`", "0.12253895353498928`", 
            "0.9024721979698485`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, {"Multivariate Kurtosis", 
          "Z", "plevel (2-tailed)"}}]]]], "Print"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 906}},
WindowSize->{895, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 74, 0, 170, "Title"],
Cell[1853, 55, 69, 1, 30, "Input"],
Cell[1925, 58, 71, 1, 30, "Input"],
Cell[1999, 61, 74, 1, 30, "Input"],
Cell[2076, 64, 69, 1, 30, "Input"],
Cell[2148, 67, 818, 18, 105, "Input"],

Cell[CellGroupData[{
Cell[2991, 89, 191, 3, 30, "Input"],
Cell[3185, 94, 533, 11, 105, "Output"]
}, Open  ]],
Cell[3733, 108, 156, 3, 50, "Input"],
Cell[3892, 113, 48, 1, 30, "Input"],
Cell[3943, 116, 86, 1, 30, "Input"],
Cell[4032, 119, 86, 1, 30, "Input"],
Cell[4121, 122, 760, 19, 249, "Input"],
Cell[4884, 143, 760, 19, 249, "Input"],
Cell[5647, 164, 140, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[5812, 171, 158, 3, 50, "Input"],
Cell[5973, 176, 137, 4, 25, "Print"],
Cell[6113, 182, 147, 4, 25, "Print"],
Cell[6263, 188, 1565, 42, 501, "Print"],
Cell[7831, 232, 376, 9, 25, "Print"],
Cell[8210, 243, 1277, 23, 101, "Print"],
Cell[9490, 268, 376, 9, 25, "Print"],
Cell[9869, 279, 1263, 23, 101, "Print"],
Cell[11135, 304, 305, 8, 25, "Print"],
Cell[11443, 314, 1257, 23, 101, "Print"],
Cell[12703, 339, 305, 8, 25, "Print"],
Cell[13011, 349, 1241, 23, 101, "Print"],
Cell[14255, 374, 161, 4, 25, "Print"],
Cell[14419, 380, 610, 15, 69, "Print"],
Cell[15032, 397, 155, 4, 25, "Print"],
Cell[15190, 403, 445, 12, 37, "Print"],
Cell[15638, 417, 166, 4, 25, "Print"],
Cell[15807, 423, 666, 16, 53, "Print"],
Cell[16476, 441, 639, 16, 53, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

